Window class

Constructors

Window(WindowType windowType)

Properties

cache Map<int, List<num>>
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
windowType WindowType
final

Methods

apply(List<num> x) List<num>
multiplyLists(List<num> factors, List<num> x) List<num>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited